@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2017 Canonical Ltd.
+ * Copyright (C) 2014-2018 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,6 +46,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
+#include <sys/uio.h>
 
 #include <linux/version.h>
 #include <linux/connector.h>
@@ -268,7 +269,7 @@ static char *get_tty(const dev_t dev)
 			continue;
 
 		if (buf.st_rdev == dev) {
-			snprintf(tty, sizeof(tty), "pts/%s", dirent->d_name);
+			snprintf(tty, sizeof(tty), "pts/%-11.11s", dirent->d_name);
 			break;
 		}
 	}
@@ -1394,7 +1395,8 @@ static void show_help(char *const argv[])
 	       "-r\trun with real time FIFO scheduler.\n"
 	       "-s\tshow short process name.\n"
 	       "-S\tshow event statistics at end of the run.\n"
-	       "-q\trun quietly and enable -S option.\n");
+	       "-q\trun quietly and enable -S option.\n"
+	       "-x\tshow extra process information.\n");
 }
 
 /*
@@ -1429,7 +1431,7 @@ static int parse_ev(char *arg)
 int main(int argc, char * const argv[])
 {
 	size_t i;
-	int sock = -1, ret = EXIT_FAILURE;
+	int sock, ret = EXIT_FAILURE;
 	struct sigaction new_action;
 
 	for (;;) {
